@@ -11,7 +11,7 @@ import ipywidgets.embed
 from traitlets import (Unicode, Bool, Dict, List, Int, Integer, observe,
                        CaselessStrEnum)
 
-from .utils import py_utils, js_utils, widget_utils
+from .utils import py_utils, widget_utils
 from .utils.py_utils import (seq_to_string, _camelize_dict, FileManager,
                              get_repr_names_from_dict, encode_base64,
                              _update_url)
@@ -1388,7 +1388,8 @@ class NGLWidget(DOMWidget):
         '''for testing
         '''
         from IPython import display
-        return display.Image(self._image_data)
+        im_bytes = base64.b64decode(self._image_data)
+        return display.Image(im_bytes)
 
     def _clear_component_auto_completion(self):
         for index, _ in enumerate(self._ngl_component_ids):
@@ -1419,21 +1420,3 @@ class NGLWidget(DOMWidget):
         """
         for i, _ in enumerate(self._ngl_component_ids):
             yield self[i]
-
-    def detach(self, split=False):
-        """detach player from its original container.
-
-        Parameters
-        ----------
-        split : bool, default False
-            if True, resize notebook then move it to the right of its container
-        """
-        if not self.loaded:
-            raise RuntimeError("must display view first")
-
-        # resize notebook first
-        # width of the dialog will be calculated based on notebook container offset
-        if split:
-            # rename
-            js_utils._move_notebook_to_the_right()
-        self._remote_call('setDialog', target='Widget')
